@@ -1,5 +1,5 @@
 from germanium.decorators import login
-from germanium.test_cases.rest import RESTTestCase
+from germanium.test_cases.rest import RestTestCase
 from germanium.tools import assert_equal
 from germanium.tools.rest import assert_valid_JSON_response
 
@@ -10,11 +10,11 @@ from issue_tracker.models import Issue
 
 
 __all__ =(
-    'RESTTestCase',
+    'RestTestCase',
 )
 
 
-class RESTTestCase(AsSuperuserTestCase, HelperTestCase, RESTTestCase):
+class RestTestCase(AsSuperuserTestCase, HelperTestCase, RestTestCase):
 
     USER_API_URL = '/api/user/'
 
